@@ -115,7 +115,7 @@ public:
         item->setData(QUrl(QStringLiteral("kcm:kcm_lookandfeel.desktop")), ResultModel::ResourceRole);
         m_defaultModel->appendRow(item);
         item = new QStandardItem();
-        item->setData(QUrl(QStringLiteral("kcm:user_manager.desktop")), ResultModel::ResourceRole);
+        item->setData(QUrl(QStringLiteral("kcm:users.desktop")), ResultModel::ResourceRole);
         m_defaultModel->appendRow(item);
         item = new QStandardItem();
         item->setData(QUrl(QStringLiteral("kcm:screenlocker.desktop")), ResultModel::ResourceRole);
@@ -359,6 +359,7 @@ void SidebarMode::initEvent()
     d->mainWidget->installEventFilter(this);
     d->mainLayout = new QHBoxLayout(d->mainWidget);
     d->mainLayout->setContentsMargins(0, 0, 0, 0);
+    d->mainLayout->setSpacing(0);
     d->moduleView = new ModuleView( d->mainWidget );
     connect( d->moduleView, &ModuleView::moduleChanged, this, &SidebarMode::moduleLoaded );
     connect(d->moduleView, &ModuleView::moduleSaved, this, &SidebarMode::updateDefaults);
@@ -421,7 +422,7 @@ void SidebarMode::showActionMenu(const QPoint &position)
     connect(menu, &QMenu::aboutToHide, this, [this] () { d->setActionMenuVisible(this, false); } );
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
-    const QStringList actionList { QStringLiteral("configure"), QStringLiteral("help_contents"), QStringLiteral("help_about_app"), QStringLiteral("help_about_kde") };
+    const QStringList actionList { QStringLiteral("configure"), QStringLiteral("help_contents"), QStringLiteral("help_report_bug"), QStringLiteral("help_about_app"), QStringLiteral("help_about_kde") };
     for (const QString &actionName : actionList) {
         menu->addAction(d->collection->action(actionName));
     }
@@ -436,18 +437,23 @@ void SidebarMode::loadModule( const QModelIndex& activeModule, const QStringList
         return;
     }
 
-    if( !d->moduleView->resolveChanges() ) {
-        return;
-    }
-
-    d->moduleView->closeModules();
-
     MenuItem *mi = activeModule.data(MenuModel::MenuItemRole).value<MenuItem *>();
 
     if (!mi) {
         return;
     }
 
+    // If we are trying to load a module already open
+    if (d->moduleView->activeModule() && mi->item() == *d->moduleView->activeModule()) {
+        return;
+    }
+
+    if( !d->moduleView->resolveChanges() ) {
+        return;
+    }
+
+    d->moduleView->closeModules();
+
     if (homeItem()) {
         d->m_introPageVisible = activeModule == d->categorizedModel->mapFromSource(d->model->indexForItem(homeItem()));
         emit introPageVisibleChanged();
@@ -574,7 +580,8 @@ void SidebarMode::updateDefaults()
     Q_ASSERT(item);
     // If subcategory exist update from subcategory
     if (!item->children().isEmpty()) {
-        item = item->child(d->activeSubCategoryRow);
+        auto subCateogryIdx = d->subCategoryModel->index(d->activeSubCategoryRow, 0);
+        item = subCateogryIdx.data(Qt::UserRole).value<MenuItem*>();
     }
     item->updateDefaultIndicator();
 
@@ -582,7 +589,8 @@ void SidebarMode::updateDefaults()
     emit d->model->dataChanged(sourceIdx, sourceIdx);
 
     auto subCateogryIdx = d->subCategoryModel->index(d->activeSubCategoryRow, 0);
-    emit d->subCategoryModel->dataChanged(subCateogryIdx, subCateogryIdx);
+    auto subCategorySourceIdx = d->categorizedModel->mapToSource(d->subCategoryModel->mapToSource(subCateogryIdx));
+    emit d->model->dataChanged(subCategorySourceIdx, subCategorySourceIdx);
 }
 
 int SidebarMode::activeSearchRow() const
